FastSplashAdDataProvider class

A TDocumentDataProvider that provides a way to persist and retrieve FastSplashAdDocument objects.

Inheritance
  • Object
  • TDataProvider
  • TDocumentDataProvider
  • FastSplashAdDataProvider

Constructors

FastSplashAdDataProvider({String storeName = kFastSplashAdStoreName})

Properties

database → TDataBaseCore
The database is the object that manages the store.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
onChanges → Stream<TStoreChanges>
Returns the stream of changes.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
store → TStore
Returns the store.
no setterinherited
storeName → String
The name of the store.
finalinherited

Methods

clearDocument() → Future<void>
Clears the document from the store.
inherited
connect() → Future<bool>
Initializes the data provider.
inherited
disconnect() → Future<bool>
Closes the data provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
persistDocument(TDocument document) → Future<void>
Persists the document in the store.
inherited
persistSplashAdDocument(FastSplashAdDocument entity) → Future<void>
Persists the document.
retrieveSplashAdDocument() → Future<FastSplashAdDocument>
Retrieves the document.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited