FastAdRaisedButton class

Inheritance

Constructors

FastAdRaisedButton({required VoidCallback? onTap, Duration trottleTimeDuration = kFastTrottleTimeDuration, bool shouldTrottleTime = false, Color? highlightColor, bool isEnabled = true, Color? textColor, EdgeInsetsGeometry? padding, Widget? child, String? text, Key? key, Color? backgroundColor, double? elevation})
const

Properties

backgroundColor → Color?
final
child → Widget?
finalinherited
disabledColor → Color?
finalinherited
elevation → double?
final
emphasis → FastButtonEmphasis
finalinherited
focusColor → Color?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
highlightColor → Color?
finalinherited
hoverColor → Color?
finalinherited
isEnabled → bool
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTap → VoidCallback?
finalinherited
padding → EdgeInsetsGeometry?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldTrottleTime → bool
finalinherited
text → String?
finalinherited
textColor → Color?
finalinherited
trottleTimeDuration → Duration
finalinherited
upperCase → bool
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → FastAdRaisedButtonState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited